==> assert-is-nonpositive-integer-0.0.7.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isNonPositiveInteger

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is a number having a nonpositive integer value.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-nonpositive-integer
```

</section>

<section class="usage">

## Usage

```javascript
var isNonPositiveInteger = require( '@stdlib/assert-is-nonpositive-integer' );
```

#### isNonPositiveInteger( value )

Tests if a `value` is a `number` having a nonpositive `integer` value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isNonPositiveInteger( -5.0 );
// returns true

bool = isNonPositiveInteger( new Number( -5.0 ) );
// returns true

bool = isNonPositiveInteger( 5.0 );
// returns false

bool = isNonPositiveInteger( -3.14 );
// returns false

bool = isNonPositiveInteger( null );
// returns false
```

#### isNonPositiveInteger.isPrimitive( value )

Tests if a `value` is a primitive `number` having a nonpositive `integer` value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isNonPositiveInteger.isPrimitive( -3.0 );
// returns true

bool = isNonPositiveInteger.isPrimitive( new Number( -3.0 ) );
// returns false
```

#### isNonPositiveInteger.isObject( value )

Tests if a `value` is a `Number` object having a nonpositive `integer` value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isNonPositiveInteger.isObject( -3.0 );
// returns false

bool = isNonPositiveInteger.isObject( new Number( -3.0 ) );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint-disable no-new-wrappers -->

<!-- eslint no-undef: "error" -->

```javascript
var Number = require( '@stdlib/number-ctor' );
var isNonPositiveInteger = require( '@stdlib/assert-is-nonpositive-integer' );

var bool = isNonPositiveInteger( -5.0 );
// returns true

bool = isNonPositiveInteger( new Number( -5.0 ) );
// returns true

bool = isNonPositiveInteger( 0.0 );
// returns true

bool = isNonPositiveInteger( -3.14 );
// returns false

bool = isNonPositiveInteger( 5.0 );
// returns false

bool = isNonPositiveInteger( '-5' );
// returns false

bool = isNonPositiveInteger( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/is-integer`][@stdlib/assert/is-integer]</span><span class="delimiter">: </span><span class="description">test if a value is a number having an integer value.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-nonpositive-integer.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-nonpositive-integer

[test-image]: https://github.com/stdlib-js/assert-is-nonpositive-integer/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-nonpositive-integer/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-nonpositive-integer?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-nonpositive-integer.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-nonpositive-integer/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-nonpositive-integer/main/LICENSE

<!-- <related-links> -->

[@stdlib/assert/is-integer]: https://www.npmjs.com/package/@stdlib/assert-is-integer

<!-- </related-links> -->

</section>

<!-- /.links -->

==> assert-is-nonpositive-integer-0.1.0.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# isNonPositiveInteger

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is a number having a nonpositive integer value.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-nonpositive-integer
```

</section>

<section class="usage">

## Usage

```javascript
var isNonPositiveInteger = require( '@stdlib/assert-is-nonpositive-integer' );
```

#### isNonPositiveInteger( value )

Tests if a `value` is a `number` having a nonpositive `integer` value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isNonPositiveInteger( -5.0 );
// returns true

bool = isNonPositiveInteger( new Number( -5.0 ) );
// returns true

bool = isNonPositiveInteger( 5.0 );
// returns false

bool = isNonPositiveInteger( -3.14 );
// returns false

bool = isNonPositiveInteger( null );
// returns false
```

#### isNonPositiveInteger.isPrimitive( value )

Tests if a `value` is a primitive `number` having a nonpositive `integer` value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isNonPositiveInteger.isPrimitive( -3.0 );
// returns true

bool = isNonPositiveInteger.isPrimitive( new Number( -3.0 ) );
// returns false
```

#### isNonPositiveInteger.isObject( value )

Tests if a `value` is a `Number` object having a nonpositive `integer` value.

<!-- eslint-disable no-new-wrappers -->

```javascript
var Number = require( '@stdlib/number-ctor' );

var bool = isNonPositiveInteger.isObject( -3.0 );
// returns false

bool = isNonPositiveInteger.isObject( new Number( -3.0 ) );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint-disable no-new-wrappers -->

<!-- eslint no-undef: "error" -->

```javascript
var Number = require( '@stdlib/number-ctor' );
var isNonPositiveInteger = require( '@stdlib/assert-is-nonpositive-integer' );

var bool = isNonPositiveInteger( -5.0 );
// returns true

bool = isNonPositiveInteger( new Number( -5.0 ) );
// returns true

bool = isNonPositiveInteger( 0.0 );
// returns true

bool = isNonPositiveInteger( -3.14 );
// returns false

bool = isNonPositiveInteger( 5.0 );
// returns false

bool = isNonPositiveInteger( '-5' );
// returns false

bool = isNonPositiveInteger( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert-is-integer`][@stdlib/assert/is-integer]</span><span class="delimiter">: </span><span class="description">test if a value is a number having an integer value.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2023. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-nonpositive-integer.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-nonpositive-integer

[test-image]: https://github.com/stdlib-js/assert-is-nonpositive-integer/actions/workflows/test.yml/badge.svg?branch=v0.1.0
[test-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/actions/workflows/test.yml?query=branch:v0.1.0

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-nonpositive-integer/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-nonpositive-integer?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-nonpositive-integer.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-nonpositive-integer/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/tree/esm
[branches-url]: https://github.com/stdlib-js/assert-is-nonpositive-integer/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-nonpositive-integer/main/LICENSE

<!-- <related-links> -->

[@stdlib/assert/is-integer]: https://www.npmjs.com/package/@stdlib/assert-is-integer

<!-- </related-links> -->

</section>

<!-- /.links -->
